--BEGIN;

CREATE INDEX "xml_att_name" ON "xml_attribute" USING BTREE ( "name" );
CREATE INDEX "xml_tag_name" ON "xml_tag" USING BTREE ( "name" );

CREATE INDEX "xml_ns_name" ON "xml_namespace" USING BTREE ( "name" );
CREATE INDEX "xml_pi_name" ON "xml_pi" USING BTREE ( "name" );

--END;